@@ -13,15 +13,14 @@
 // limitations under the License.
 
 //go:build aix || darwin || dragonfly || freebsd || (js && wasm) || linux || netbsd || openbsd || solaris
-// +build aix darwin dragonfly freebsd js,wasm linux netbsd openbsd solaris
 
 package buffetch
 
 import (
 	"testing"
 
+	"buf.build/go/app"
 	"github.com/bufbuild/buf/private/buf/buffetch/internal"
-	"github.com/bufbuild/buf/private/pkg/app"
 )
 
 func TestGetParsedRefSuccess_UnixOnly(t *testing.T) {
