@@ -18,6 +18,7 @@ import (
 	"errors"
 	"fmt"
 	"regexp"
+	"slices"
 	"strings"
 	"unicode/utf8"
 
@@ -32,6 +33,7 @@ import (
 	"google.golang.org/protobuf/types/dynamicpb"
 	"google.golang.org/protobuf/types/known/anypb"
 	"google.golang.org/protobuf/types/known/durationpb"
+	"google.golang.org/protobuf/types/known/fieldmaskpb"
 	"google.golang.org/protobuf/types/known/timestamppb"
 	"google.golang.org/protobuf/types/known/wrapperspb"
 )
@@ -67,6 +69,7 @@ const (
 	requiredFieldNumber       = 25
 	ignoreEmptyFieldNumber    = 26
 	ignoreFieldNumber         = 27
+	fieldMaskRulesFieldNumber = 28
 	// https://buf.build/bufbuild/protovalidate/docs/v0.5.1:buf.validate#buf.validate.StringRules
 	minLenFieldNumberInStringRules         = 2
 	maxLenFieldNumberInStringRules         = 3
@@ -98,6 +101,8 @@ const (
 	ltNowFieldNumberInTimestampRules  = 7
 	gtNowFieldNumberInTimestampRules  = 8
 	withInFieldNumberInTimestampRules = 9
+	// https://buf.build/bufbuild/protovalidate/docs/v1.1.0:buf.validate#buf.validate.FieldMaskRules
+	inFieldMaskRules = 2
 
 	exampleName = "example"
 )
@@ -134,6 +139,7 @@ var (
 		anyRulesFieldNumber:       string((&anypb.Any{}).ProtoReflect().Descriptor().FullName()),
 		durationRulesFieldNumber:  string((&durationpb.Duration{}).ProtoReflect().Descriptor().FullName()),
 		timestampRulesFieldNumber: string((&timestamppb.Timestamp{}).ProtoReflect().Descriptor().FullName()),
+		fieldMaskRulesFieldNumber: string((&fieldmaskpb.FieldMask{}).ProtoReflect().Descriptor().FullName()),
 	}
 	wrapperTypeNames = map[string]struct{}{
 		string((&wrapperspb.FloatValue{}).ProtoReflect().Descriptor().FullName()):  {},
@@ -215,7 +221,7 @@ func checkRulesForField(
 			adder.getFieldRuleName(requiredFieldNumber),
 		)
 	}
-	checkFieldFlags(adder, fieldRules)
+	checkFieldFlags(adder, fieldDescriptor, fieldRules)
 	if err := checkCELForField(
 		adder,
 		fieldRules,
@@ -290,12 +296,15 @@ func checkRulesForField(
 		return checkDurationRules(adder, fieldRules.GetDuration())
 	case timestampRulesFieldNumber:
 		return checkTimestampRules(adder, fieldRules.GetTimestamp())
+	case fieldMaskRulesFieldNumber:
+		checkFieldMaskRules(adder, fieldRules.GetFieldMask())
 	}
 	return nil
 }
 
 func checkFieldFlags(
 	adder *adder,
+	fieldDescriptor protoreflect.FieldDescriptor,
 	fieldRules *validate.FieldRules,
 ) {
 	var fieldCount int
@@ -313,7 +322,7 @@ func checkFieldFlags(
 			adder.getFieldRuleName(),
 		)
 	}
-	if fieldRules.GetRequired() && fieldRules.GetIgnore() == validate.Ignore_IGNORE_IF_UNPOPULATED {
+	if fieldRules.GetRequired() && fieldRules.GetIgnore() == validate.Ignore_IGNORE_IF_ZERO_VALUE {
 		adder.addForPathsf(
 			[][]int32{
 				{requiredFieldNumber},
@@ -323,7 +332,16 @@ func checkFieldFlags(
 			adder.fieldName(),
 			adder.getFieldRuleName(requiredFieldNumber),
 			adder.getFieldRuleName(ignoreFieldNumber),
-			validate.Ignore_IGNORE_IF_UNPOPULATED,
+			validate.Ignore_IGNORE_IF_ZERO_VALUE,
+		)
+	}
+	if fieldRules.GetIgnore() == validate.Ignore_IGNORE_IF_ZERO_VALUE && fieldDescriptor.HasPresence() && !fieldDescriptor.IsExtension() {
+		adder.addForPathf(
+			[]int32{ignoreFieldNumber},
+			"Field %q has %s=%v and tracks presence. This is the same the default and the ignore option can be removed.",
+			adder.fieldName(),
+			adder.getFieldRuleName(ignoreFieldNumber),
+			validate.Ignore_IGNORE_IF_ZERO_VALUE,
 		)
 	}
 }
@@ -376,13 +394,13 @@ func checkRulesForExtension(
 			adder.getFieldRuleName(requiredFieldNumber),
 		)
 	}
-	if fieldRules.GetIgnore() == validate.Ignore_IGNORE_IF_UNPOPULATED {
+	if fieldRules.GetIgnore() == validate.Ignore_IGNORE_IF_ZERO_VALUE {
 		adder.addForPathf(
 			[]int32{ignoreFieldNumber},
 			"Field %q is an extension field and cannot have %s=%v.",
 			adder.fieldName(),
 			adder.getFieldRuleName(ignoreFieldNumber),
-			validate.Ignore_IGNORE_IF_UNPOPULATED,
+			validate.Ignore_IGNORE_IF_ZERO_VALUE,
 		)
 	}
 }
@@ -728,6 +746,22 @@ func checkTimestampRules(adder *adder, timestampRules *validate.TimestampRules)
 	return nil
 }
 
+func checkFieldMaskRules(adder *adder, fieldMaskRules *validate.FieldMaskRules) {
+	checkConst(adder, fieldMaskRules, fieldMaskRulesFieldNumber)
+	if len(fieldMaskRules.In) > 0 && len(fieldMaskRules.NotIn) > 0 {
+		for _, in := range fieldMaskRules.In {
+			if slices.Contains(fieldMaskRules.NotIn, in) {
+				adder.addForPathf(
+					[]int32{fieldMaskRulesFieldNumber, inFieldMaskRules},
+					"Field %q has path %q in both in and not_in rules.",
+					adder.fieldName(),
+					in,
+				)
+			}
+		}
+	}
+}
+
 func checkExampleValues(
 	adder *adder,
 	pathToExampleValues []int32,
@@ -1138,11 +1172,12 @@ func checkLenRules(
 				{ruleFieldNumber, minLenFieldNumber},
 				{ruleFieldNumber, maxLenFieldNumber},
 			},
-			"Field %q has equal %s and %s, use %s.const instead.",
+			"Field %q has equal %s and %s, use %s.%s instead.",
 			adder.fieldName(),
 			adder.getFieldRuleName(ruleFieldNumber, minLenFieldNumber),
 			maxLenFieldName,
 			adder.getFieldRuleName(ruleFieldNumber),
+			lenFieldName,
 		)
 	}
 	return nil
