@@ -616,6 +616,10 @@ func TestRunProtovalidate(t *testing.T) {
 		bufanalysistesting.NewFileAnnotation(t, "bytes.proto", 31, 5, 31, 45, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "bytes.proto", 43, 5, 43, 65, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "bytes.proto", 46, 45, 46, 106, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "cel_expression.proto", 11, 37, 11, 85, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "cel_expression.proto", 14, 38, 14, 84, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "cel_expression.proto", 19, 5, 19, 53, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "cel_expression.proto", 25, 3, 25, 65, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_field.proto", 10, 37, 14, 4, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_field.proto", 17, 5, 21, 6, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "cel_field.proto", 29, 5, 33, 6, "PROTOVALIDATE"),
@@ -659,6 +663,9 @@ func TestRunProtovalidate(t *testing.T) {
 		bufanalysistesting.NewFileAnnotation(t, "field.proto", 18, 5, 18, 41, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "field.proto", 19, 5, 19, 55, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "field.proto", 23, 52, 23, 102, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "field_mask.proto", 16, 45, 16, 88, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "field_mask.proto", 20, 5, 22, 6, "PROTOVALIDATE"),
+		bufanalysistesting.NewFileAnnotation(t, "field_mask.proto", 31, 5, 31, 45, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 24, 38, 24, 76, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 27, 5, 27, 43, "PROTOVALIDATE"),
 		bufanalysistesting.NewFileAnnotation(t, "map.proto", 29, 5, 29, 43, "PROTOVALIDATE"),
